Learn R Programming

vacem (version 0.1-1)

E.vacc: Calculates the expected number of vaccinations for individuals.

Description

Calculates the expected number of vaccinations for individuals.

Usage

E.vacc(z, w, v, N, alpha, rho, log=FALSE, cond.on.accessible=FALSE)

Arguments

z
the eligibility vector for the individual, i.e. @codez[j] = 1 if this individual is eligible for campaign @c j, otherwise @codez[j] = 0
w
the weight vector for the individual, i.e. @code w[k] gives the probability of the individual receiving the routine vaccination in year @c k
v
the doses vector providing the number of vaccine doses nominally distributed in each campaign
N
the population size vector specifying the number of people in the target age range for each campaign
alpha
the vaccination efficiency parameter (scalar) for the campaign; @codealpha = -inf implies perfect efficiency, @codealpha = 0 implies random efficiency; see note above
rho
the proportion of the population (scalar) that can be vaccinated, i.e @code1 - rho is the @e inaccessible portion of the general population.
log
a flag indicating whether the log probability should be returned; the default is @c FALSE NOTE: the @c log parameter is @b not currently used.
cond.on.accessible
a flag indicating whether the return value should be conditioned on the individual's inclusion in the accessible population, i.e. @p rho; the default is @c FALSE

Value

eligibility vector @p z and weight vector @p w during the campaigns described by @p v and @p N

Details

The @c E.vacc function complements the probability calculation @c g and computes the expected vaccination count that an individual would have received during a specified set of vaccination activities. The vaccination activities are described by inputs @p v and @p N; @p v provides the number of doses distributed and @p N provides the target population size for each activity. An individual's probability is determined by inputs @p z and @p w; @p z indicates which activities the individual is eligible for and @p w provides the pseudo-campaign weighting that specifies the probability of child receiving a routine vaccination each year. Finally, the scalar parameters, @p alpha and @p rho, quantify campaign efficiency and the size of accessible population, respectively.