Learn R Programming

vacem (version 0.1-1)

g: Calculates the vaccination probability for individuals.

Description

Calculates the vaccination probability for individuals.

Usage

g(z, w, v, N, alpha, rho, log=FALSE)

Arguments

z
the eligibility vector for the individual, i.e. @codez[j] = 1 if this individual is eligible for campaign @c j, otherwise @codez[j] = 0
w
the weight vector for the individual, i.e. @code w[k] gives the probability of the individual receiving the routine vaccination in year @c k
v
the doses vector providing the number of vaccine doses nominally distributed in each campaign
N
the population size vector specifying the number of people in the target age range for each campaign
alpha
the vaccination efficiency parameter (scalar) for the campaign; @codealpha = -inf implies perfect efficiency, @codealpha = 0 implies random efficiency; see note above
rho
the proportion of the population (scalar) that can be vaccinated, i.e @code1 - rho is the @e inaccessible portion of the general population.
log
a flag indicating whether the log probability should be returned; the default is @c FALSE

Value

vector @p z and weight vector @p w during the campaigns described by @p v and @p N

Details

The @c g function is used to calculate the probability that an individual has been vaccinated during a set of vaccination activities. The vaccination activities are described by inputs @p v and @p N; @p v specifies the number of doses distributed and @p N specifies the target population size for each activity. An individual's probability is determined by inputs @p z and @p w; @p z indicates which activities the individual is eligible for and @p w provides the pseudo-campaign weighting that specifies the probability of child receiving a routine vaccination each year. Finally, the scalar parameters, @p alpha and @p rho, quantify campaign efficiency and the size of accessible population, respectively.