Learn R Programming

vacem (version 0.1-1)

nine.month.pointmass: Defines a simple cumulative distribution function (CDF) with...

Description

Defines a simple cumulative distribution function (CDF) with a point mass at nine (9) months.

Usage

nine.month.pointmass(age)

Arguments

age
the age of the individual

Value

@p age < 9 and one (1) otherwise@see w.matrix @see ll.coverage @see mcmc.estimate

Details

The cumulative distribution function determines an individual's probabilty of receiving a routine vaccination. It is passed into the weighting calculation function (@codew.matrix) by various coverage analysis functions such as @code ll.coverage and @code mcmc.estimate . A user specifies, by name, which CDF to use when an analysis function is invoked, e.g. @code mcmc.estimate( ..., routine.cdf = "9m.pointmass", ... ) . See the documentation for the respective analysis functions for details about which CDFs are supported.

Examples

Run this code
plot( x=x, y=nine.month.pointmass(x) )

Run the code above in your browser using DataLab