Learn R Programming

vacem (version 0.1-1)

vacem-package: Vaccination Activities Coverage Estimation Model

Description

A likelihood framework for estimating the effective coverage of vaccination programs using cross-sectional surveys combined with administrative data.

Arguments

Details

Package:
vacem
Type:
Package
Version:
0.1-1
Date:
2012-01-30
License:
GPL (>= 2)
LazyLoad:
yes

The performance of routine and supplemental immunization activities is usually measured by the administrative method: dividing the number of doses distributed by the size of the target population. This package implements a method that combines the administrative data with measurements from cross-sectional surveys of vaccine coverage, e.g. Demographic and Health Surveys (DHS), to provide an improved estimate of vaccination coverage.

References

Lessler J, Metcalf CJE, Grais RF, Luquero FJ, Cummings DAT, et al. (2011) Measuring the Performance of Vaccination Programs Using Cross-Sectional Surveys: A Likelihood Framework and Retrospective Analysis. PLoS Med 8(10): e1001110. doi:10.1371/journal.pmed.1001110 http://www.plosmedicine.org/article/info:doi/10.1371/journal.pmed.1001110