Arguments
z
the eligibility vector for the individual, i.e. @codez[j] = 1
if this individual is eligible for campaign @c j, otherwise
@codez[j] = 0
w
the weight vector for the individual, i.e. @code w[k] gives
the probability of the individual receiving the routine
vaccination in year @c k
v
the doses vector providing the number of vaccine doses nominally
distributed in each campaign
N
the population size vector specifying the number of people in
the target age range for each campaign
alpha
the vaccination efficiency parameter (scalar) for the campaign;
@codealpha = -inf implies perfect efficiency,
@codealpha = 0 implies random efficiency; see note above
rho
the proportion of the population (scalar) that can be vaccinated,
i.e @code1 - rho is the @e inaccessible portion of the
general population.
log
a flag indicating whether the log probability should be
returned; the default is @c FALSE